@@ -21,18 +21,16 @@ Example:
 """
 from __future__ import annotations
 
-from typing import Any, List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from rdflib import Graph, Literal, Namespace, RDF, URIRef
-from skolemizer import Skolemizer
+from skolemizer import Skolemizer  # type: ignore
 
 from .catalogrecord import CatalogRecord
 from .dataservice import DataService
 from .dataset import Dataset
-from .resource import Resource
 from .uri import URI
 
-
 DCT = Namespace("http://purl.org/dc/terms/")
 DCAT = Namespace("http://www.w3.org/ns/dcat#")
 FOAF = Namespace("http://xmlns.com/foaf/0.1/")
@@ -54,21 +52,19 @@ class Catalog(Dataset):
         "_services",
         "_catalogs",
         "_catalogrecords",
-        "_models",
-        "_contains_services",
         "_dct_identifier",
+        "_type",
     )
 
     _homepage: URI
     _themes: List[str]
-    _has_parts: List[Resource]
+    _has_parts: List[Catalog]
     _datasets: List[Dataset]
     _services: List[DataService]
     _catalogs: List[Catalog]
     _catalogrecords: List[CatalogRecord]
-    _models: List[Any]
-    _contains_services: List[Any]
     _dct_identifier: str
+    _type: URIRef
 
     def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits catalog object with default values."""
@@ -84,8 +80,6 @@ class Catalog(Dataset):
         self.services = []
         self.catalogs = []
         self.catalogrecords = []
-        self.models = []
-        self.contains_services = []
 
     @property
     def homepage(self: Catalog) -> str:
@@ -106,12 +100,12 @@ class Catalog(Dataset):
         self._themes = themes
 
     @property
-    def has_parts(self: Catalog) -> List[Resource]:
-        """List[Resource]: A list of resources that is listed in the catalog."""
+    def has_parts(self: Catalog) -> List[Catalog]:
+        """List[Catalog]: A list of resources that is listed in the catalog."""
         return self._has_parts
 
     @has_parts.setter
-    def has_parts(self: Catalog, has_parts: List[Resource]) -> None:
+    def has_parts(self: Catalog, has_parts: List[Catalog]) -> None:
         self._has_parts = has_parts
 
     @property
@@ -123,24 +117,6 @@ class Catalog(Dataset):
     def datasets(self: Catalog, datasets: List[Dataset]) -> None:
         self._datasets = datasets
 
-    @property
-    def models(self: Catalog) -> List[Any]:
-        """List[URI]: A list of links to InformationModels."""
-        return self._models
-
-    @models.setter
-    def models(self: Catalog, models: List[Any]) -> None:
-        self._models = models
-
-    @property
-    def contains_services(self: Catalog) -> List[Any]:
-        """List[URI]: A list of links to Services."""
-        return self._contains_services
-
-    @contains_services.setter
-    def contains_services(self: Catalog, contains_services: List[Any]) -> None:
-        self._contains_services = contains_services
-
     @property
     def services(self: Catalog) -> List[DataService]:
         """List[DataService]: A list of dataservices of sites or end-points that is listed in the catalog."""  # noqa: B950
@@ -177,7 +153,7 @@ class Catalog(Dataset):
     def dct_identifier(self, dct_identifier: str) -> None:
         self._dct_identifier = dct_identifier
 
-        # -
+    # -
 
     def to_rdf(
         self: Catalog,
@@ -185,8 +161,6 @@ class Catalog(Dataset):
         encoding: Optional[str] = "utf-8",
         include_datasets: bool = True,
         include_services: bool = True,
-        include_models: bool = True,
-        include_contains_services: bool = True,
     ) -> Union[bytes, str]:
         """Maps the catalog to rdf.
 
@@ -200,8 +174,6 @@ class Catalog(Dataset):
             encoding (str): the encoding to serialize into
             include_datasets (bool): includes the dataset graphs in the catalog
             include_services (bool): includes the services in the catalog
-            include_models (bool): includes the models in the catalog
-            include_contains_services (bool): includes the services (cpsvno) in the catalog
 
         Returns:
             a rdf serialization as a bytes literal according to format.
@@ -209,8 +181,6 @@ class Catalog(Dataset):
         return self._to_graph(
             include_datasets,
             include_services,
-            include_models,
-            include_contains_services,
         ).serialize(format=format, encoding=encoding)
 
     # -
@@ -219,8 +189,6 @@ class Catalog(Dataset):
         self: Catalog,
         include_datasets: bool = True,
         include_services: bool = True,
-        include_models: bool = True,
-        include_contains_services: bool = True,
     ) -> Graph:
 
         if not getattr(self, "identifier", None):
@@ -240,8 +208,6 @@ class Catalog(Dataset):
         self._services_to_graph()
         self._catalogs_to_graph()
         self._catalogrecords_to_graph()
-        self._models_to_graph()
-        self._contains_services_to_graph()
 
         # Add all the datasets to the graf
         if include_datasets:
@@ -253,16 +219,6 @@ class Catalog(Dataset):
             for service in self._services:
                 self._g += service._to_graph()
 
-        # Add all the models to the graf
-        if include_models:
-            for model in self._models:
-                self._g += model._to_graph()
-
-        # Add all the contains_services  to the graf
-        if include_contains_services:
-            for service in self._contains_services:
-                self._g += service._to_graph()
-
         return self._g
 
     def _dct_identifier_to_graph(self: Dataset) -> None:
@@ -362,24 +318,20 @@ class Catalog(Dataset):
                     )
                 )
 
-    def _models_to_graph(self: Catalog) -> None:
-        if getattr(self, "models", None):
-            for _model in self._models:
-                self._g.add(
-                    (
-                        URIRef(self.identifier),
-                        MODELLDCATNO.model,
-                        URIRef(_model.identifier),
-                    )
-                )
+    @classmethod
+    def _attr_from_json(cls: Any, attr: str, json_dict: Dict) -> Any:
+        obj = Dataset._attr_from_json(attr, json_dict)
+        if obj is not None:
+            return obj
 
-    def _contains_services_to_graph(self: Catalog) -> None:
-        if getattr(self, "contains_services", None):
-            for _service in self._contains_services:
-                self._g.add(
-                    (
-                        URIRef(self.identifier),
-                        DCATNO.containsService,
-                        URIRef(_service.identifier),
-                    )
-                )
+        if attr == "has_parts":
+            return Catalog.from_json(json_dict)
+        if attr == "datasets":
+            return Dataset.from_json(json_dict)
+        if attr == "services":
+            return DataService.from_json(json_dict)
+        if attr == "catalogs":
+            return Catalog.from_json(json_dict)
+        if attr == "catalogrecords":
+            return CatalogRecord.from_json(json_dict)
+        return None
