@@ -16,7 +16,7 @@ Example:
 """
 from __future__ import annotations
 
-from typing import List, Optional
+from typing import Any, Dict, List, Optional, TYPE_CHECKING
 
 from rdflib import Graph, Namespace, RDF, URIRef
 from skolemizer import Skolemizer
@@ -25,6 +25,9 @@ from .dataset import Dataset
 from .resource import Resource
 from .uri import URI
 
+if TYPE_CHECKING:  # pragma: no cover
+    pass
+
 DCT = Namespace("http://purl.org/dc/terms/")
 DCAT = Namespace("http://www.w3.org/ns/dcat#")
 
@@ -65,7 +68,8 @@ class DataService(Resource):
 
     @property
     def endpointDescription(self: DataService) -> str:
-        """URI: A description of the services available via the end-points, including their operations, parameters etc."""  # noqa: B950
+        """URI: A description of the services available via the end-points, including their operations, parameters etc."""
+        # noqa: B950
         return self._endpointDescription
 
     @endpointDescription.setter
@@ -91,6 +95,35 @@ class DataService(Resource):
         self._media_types = media_types
 
     # -
+    @classmethod
+    def from_json(cls, json: Dict) -> Resource:
+        """Convert a JSON (dict).
+
+        Args:
+            json: A dict representing this class.
+
+        Returns:
+            Resource: The object.
+        """
+        resource = cls()
+        for key in json:
+            is_private = key.startswith("_")
+            if not is_private:
+                v = json[key]
+                if isinstance(v, list):
+                    alist = []
+                    for i in v:
+                        attr = cls._attr_from_json(key, i)
+                        if attr is not None:
+                            alist.append(attr)
+                        else:
+                            alist.append(i)
+                    setattr(resource, key, alist)
+                else:
+                    setattr(resource, key, v)
+
+        return resource
+
     def _to_graph(self: DataService) -> Graph:
 
         if not getattr(self, "identifier", None):
@@ -147,3 +180,14 @@ class DataService(Resource):
 
         for _media_type in self.media_types:
             self._g.add((URIRef(self.identifier), DCAT.mediaType, URIRef(_media_type)))
+
+    @classmethod
+    def _attr_from_json(cls, attr: str, json_dict: Dict) -> Any:
+        obj = Resource._attr_from_json(attr, json_dict)
+        if obj is not None:
+            return obj
+
+        if attr == "servesdatasets":
+            return Dataset.from_json(json_dict)
+
+        return None
