@@ -2,7 +2,7 @@
 
 This module contains methods for mapping a document object to rdf
 according to the
-`dcat-ap-no v.2 standard <https://doc.difi.no/review/dcat-ap-no/#klasse-distribusjon>`__
+`dcat-ap-no v.2 standard <https://data.norge.no/specification/dcat-ap-no/#klasse-dokument>`__
 
 Example:
     >>> from datacatalogtordf import Document
@@ -13,10 +13,10 @@ Example:
 """
 from __future__ import annotations
 
-from typing import Optional
+from typing import Dict, Optional, Union
 
 from rdflib import DCTERMS, FOAF, Graph, Literal, Namespace, RDF, URIRef
-from skolemizer import Skolemizer
+from skolemizer import Skolemizer  # type: ignore
 
 from datacatalogtordf.uri import URI
 
@@ -24,65 +24,98 @@ DCAT = Namespace("http://www.w3.org/ns/dcat#")
 
 
 class Document:
-    """A class representing a foaf:Document.
+    """A class representing a foaf:Document."""
 
-    Attributes:
-        identifier (URI): A URI uniquely identifying the document
-        title (dict): A title given to the document. key is langauge code
-        language (str): A reference to the language which is used in the document
-        format (str): A link to a concept designating the type of the document
-    """
-
-    slots = (
+    __slots__ = (
+        "_g",
         "_identifier",
         "_title",
         "_language",
     )
 
+    _g: Graph
     _identifier: URI
-    _title: dict
-    _language: str
-    _type: str
+    _title: Dict[str, str]
+    _language: URI
 
     def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
         if identifier:
             self.identifier = identifier
-        self._type = FOAF.Document
 
     @property
     def identifier(self: Document) -> str:
-        """Get for identifier."""
+        """URI: A URI uniquely identifying the document."""
         return self._identifier
 
     @identifier.setter
     def identifier(self: Document, identifier: str) -> None:
-        """Set for identifier."""
         self._identifier = URI(identifier)
 
     @property
-    def title(self) -> dict:
-        """Get for title attribute."""
+    def title(self) -> Dict[str, str]:
+        """Dict[str, str]: A title given to the document. key is langauge code."""
         return self._title
 
     @title.setter
-    def title(self, title: dict) -> None:
-        """Set for title attribute."""
+    def title(self, title: Dict[str, str]) -> None:
         self._title = title
 
     @property
     def language(self: Document) -> str:
-        """Get for language."""
+        """str: A reference to the language which is used in the document."""
         return self._language
 
     @language.setter
     def language(self: Document, language: str) -> None:
-        """Set for language."""
         self._language = URI(language)
 
+    # -
+    def to_json(self) -> Dict:
+        """Convert the Resource to a json / dict. It will omit the non-initalized fields.
+
+        Returns:
+            Dict: The json representation of this instance.
+        """
+        output = {"_type": type(self).__name__}
+        # Add ins for optional top level attributes
+        for k in dir(self):
+            try:
+                v = getattr(self, k)
+                is_method = callable(v)
+                is_private = k.startswith("_")
+                if is_method or is_private:
+                    continue
+
+                to_json = hasattr(v, "to_json") and callable(getattr(v, "to_json"))
+                output[k] = v.to_json() if to_json else v
+
+            except AttributeError:
+                continue
+
+        return output
+
+    @classmethod
+    def from_json(cls, json: Dict) -> Document:
+        """Convert a JSON (dict).
+
+        Args:
+            json: A dict representing this class.
+
+        Returns:
+             Document: The object.
+        """
+        resource = cls()
+        for key in json:
+            is_private = key.startswith("_")
+            if not is_private:
+                setattr(resource, key, json[key])
+
+        return resource
+
     def to_rdf(
         self: Document, format: str = "turtle", encoding: Optional[str] = "utf-8"
-    ) -> bytes:
+    ) -> Union[bytes, str]:
         """Maps the document to rdf.
 
         Args:
