@@ -9,13 +9,13 @@ Refer to sub-class for typical usage examples.
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Dict, List, Optional, TYPE_CHECKING, Union
+from typing import Any, Dict, List, Optional, TYPE_CHECKING, Union
 
-from concepttordf import Contact
 from rdflib import BNode, Graph, Literal, Namespace, RDF, URIRef
 from rdflib.term import Identifier
 
 from .agent import Agent
+from .contact import Contact
 from .periodoftime import Date
 from .uri import URI
 
@@ -41,7 +41,7 @@ class Resource(ABC):
     __slots__ = (
         "_g",
         "_access_rights",
-        "_conformsTo",
+        "_conforms_to",
         "_contactpoint",
         "_creator",
         "_description",
@@ -68,7 +68,7 @@ class Resource(ABC):
     # Types
     _g: Graph
     _access_rights: URI  # 6.4.1
-    _conformsTo: List[str]  # 6.4.2
+    _conforms_to: List[str]  # 6.4.2
     _contactpoint: Contact  # 6.4.3
     _creator: URI  # 6.4.4
     _description: Dict[str, str]  # 6.4.5
@@ -96,7 +96,7 @@ class Resource(ABC):
         """Inits an object with default values."""
         self._type = DCAT.Resource
         # Initalize lists:
-        self.conformsTo = list()
+        self.conforms_to = list()
         self.theme = list()
         self.is_referenced_by = list()
         self.qualified_attributions = list()
@@ -151,13 +151,16 @@ class Resource(ABC):
         self._access_rights = URI(access_rights)
 
     @property
-    def conformsTo(self: Resource) -> List[str]:
+    def conforms_to(self: Resource) -> List[str]:
         """List[URI]: A list of links to established standards to which the described resource conforms."""  # noqa: B950
-        return self._conformsTo
+        return self._conforms_to
 
-    @conformsTo.setter
-    def conformsTo(self: Resource, conformsTo: List[str]) -> None:
-        self._conformsTo = conformsTo
+    @conforms_to.setter
+    def conforms_to(self: Resource, conforms_to: List[str]) -> None:
+        # Validate conforms_to URIs:
+        for string in conforms_to:
+            URI(string)
+        self._conforms_to = conforms_to
 
     @property
     def theme(self: Resource) -> List[str]:
@@ -166,6 +169,9 @@ class Resource(ABC):
 
     @theme.setter
     def theme(self: Resource, theme: List[str]) -> None:
+        # Validate theme URIs:
+        for string in theme:
+            URI(string)
         self._theme = theme
 
     @property
@@ -249,6 +255,9 @@ class Resource(ABC):
 
     @landing_page.setter
     def landing_page(self: Resource, landing_page: List[str]) -> None:
+        # Validate landing_page URIs:
+        for string in landing_page:
+            URI(string)
         self._landing_page = landing_page
 
     @property
@@ -276,11 +285,18 @@ class Resource(ABC):
 
     @resource_relation.setter
     def resource_relation(self: Resource, resource_relation: List[str]) -> None:
+        # Validate resource_relation URIs:
+        for string in resource_relation:
+            URI(string)
         self._resource_relation = resource_relation
 
     @property
     def rights(self: Resource) -> str:
-        """URI: A link to a statement that concerns all rights not addressed with dct:license or dct:accessRights, such as copyright statements."""  # noqa: B950
+        """URI: A link to a statement that concerns all rights not addressed with dct:license or dct:accessRights, such as copyright statements.
+
+        Returns:
+            str: The link
+        """  # noqa: B950
         return self._rights
 
     @rights.setter
@@ -317,6 +333,93 @@ class Resource(ABC):
         self._prev = prev
 
     # -
+    def to_json(self) -> Dict:
+        """Convert the Resource to a json / dict. It will omit the non-initalized fields.
+
+        Returns:
+            Dict: The json representation of this instance.
+        """
+        output: Dict = {"_type": type(self).__name__}
+        # Add ins for optional top level attributes
+        for k in dir(self):
+            try:
+                v = getattr(self, k)
+                is_method = callable(v)
+                is_private = k.startswith("_")
+                if is_method or is_private:
+                    continue
+
+                if isinstance(v, list):
+                    output[k] = []
+                    for i in v:
+                        to_json = hasattr(i, "to_json") and callable(
+                            getattr(i, "to_json")
+                        )
+                        output[k].append(i.to_json() if to_json else i)
+                else:
+                    to_json = hasattr(v, "to_json") and callable(getattr(v, "to_json"))
+                    output[k] = v.to_json() if to_json else v
+
+            except AttributeError:
+                continue
+
+        return output
+
+    @classmethod
+    def from_json(cls, json: Dict) -> Resource:
+        """Convert a JSON (dict).
+
+        Args:
+            json: A dict representing this class.
+
+        Returns:
+            Resource: The object.
+        """
+        resource = cls()
+        for key in json:
+            is_private = key.startswith("_")
+            if not is_private:
+                v = json[key]
+                if isinstance(v, list):
+                    alist = []
+                    for i in v:
+                        attr = cls._attr_from_json(key, i)
+                        if attr is not None:
+                            alist.append(attr)
+                        else:
+                            alist.append(i)
+                    setattr(resource, key, alist)
+                else:
+                    attr = cls._attr_from_json(key, v)
+                    if attr is not None:
+                        setattr(resource, key, attr)
+                    else:
+                        setattr(resource, key, v)
+
+        return resource
+
+    @classmethod
+    def _attr_from_json(cls: Any, attr: str, json_dict: Dict) -> Any:
+        if attr == "contactpoint":
+            return Contact.from_json(json_dict)
+        if attr == "publisher":
+            return Agent.from_json(json_dict)
+        if attr == "qualified_relation":
+            # Prevent circular import
+            clazz = getattr(__import__("datacatalogtordf"), "Relationship")
+            return clazz.from_json(json_dict)
+        if attr == "is_referenced_by" or attr == "prev":
+            if (
+                isinstance(json_dict, dict)
+                and "_type" in json_dict.keys()
+                and json_dict["_type"]
+                in ["Catalog", "Dataset", "DatasetSeries", "DataService"]
+            ):
+                clazz = getattr(__import__("datacatalogtordf"), json_dict["_type"])
+                return clazz.from_json(json_dict)
+
+        return None
+
     def to_rdf(
         self: Resource, format: str = "turtle", encoding: Optional[str] = "utf-8"
     ) -> Union[bytes, str]:
@@ -360,7 +463,7 @@ class Resource(ABC):
         self._publisher_to_graph()
         self._title_to_graph()
         self._access_rights_to_graph()
-        self._conformsTo_to_graph()
+        self._conforms_to_to_graph()
         self._description_to_graph()
         self._theme_to_graph()
         self._contactpoint_to_graph()
@@ -416,9 +519,9 @@ class Resource(ABC):
                 (URIRef(self.identifier), DCT.accessRights, URIRef(self.access_rights))
             )
 
-    def _conformsTo_to_graph(self: Resource) -> None:
-        if getattr(self, "conformsTo", None):
-            for _c in self.conformsTo:
+    def _conforms_to_to_graph(self: Resource) -> None:
+        if getattr(self, "conforms_to", None):
+            for _c in self.conforms_to:
                 _uri = URI(_c)
                 self._g.add((URIRef(self.identifier), DCT.conformsTo, URIRef(_uri)))
 
@@ -442,10 +545,10 @@ class Resource(ABC):
     def _contactpoint_to_graph(self: Resource) -> None:
         if getattr(self, "contactpoint", None):
             contact = self.contactpoint
-            contactPoint = BNode()
+            contact_point = BNode()
             for _s, p, o in contact._to_graph().triples((None, None, None)):
-                self._g.add((contactPoint, p, o))
-            self._g.add((URIRef(self.identifier), DCAT.contactPoint, contactPoint))
+                self._g.add((contact_point, p, o))
+            self._g.add((URIRef(self.identifier), DCAT.contactPoint, contact_point))
 
     def _creator_to_graph(self: Resource) -> None:
         if getattr(self, "creator", None):
